@@ -1,5 +1,8 @@
 """Postgres database implementation."""
-from typing import Dict, List
+from __future__ import annotations
+
+import io
+from contextlib import closing
 
 import pandas as pd
 import sqlalchemy
@@ -8,7 +11,7 @@ from psycopg2 import sql as postgres_sql
 
 from astro.constants import DEFAULT_CHUNK_SIZE, LoadExistStrategy, MergeConflictStrategy
 from astro.databases.base import BaseDatabase
-from astro.settings import SCHEMA
+from astro.settings import POSTGRES_SCHEMA
 from astro.sql.table import Metadata, Table
 
 DEFAULT_CONN_ID = PostgresHook.default_conn_name
@@ -20,8 +23,9 @@ class PostgresDatabase(BaseDatabase):
     logic in other parts of our code-base.
     """
 
-    illegal_column_name_chars: List[str] = ["."]
-    illegal_column_name_chars_replacement: List[str] = ["_"]
+    DEFAULT_SCHEMA = POSTGRES_SCHEMA
+    illegal_column_name_chars: list[str] = ["."]
+    illegal_column_name_chars_replacement: list[str] = ["_"]
 
     def __init__(self, conn_id: str = DEFAULT_CONN_ID):
         super().__init__(conn_id)
@@ -37,9 +41,20 @@ class PostgresDatabase(BaseDatabase):
 
     @property
     def default_metadata(self) -> Metadata:
-        """Fill in default metadata values for table objects addressing postgres databases"""
+        """
+        Fill in default metadata values for table objects addressing Postgres databases.
+
+        Currently, Schema is not being fetched from airflow connection for Postgres because, in Postgres, databases and
+        schema are different concepts: https://www.postgresql.org/docs/current/ddl-schemas.html
+        The PostgresHook only exposes schema:
+        https://airflow.apache.org/docs/apache-airflow-providers-postgres/stable/_api/airflow/providers/postgres/hooks/postgres/index.html
+        However, implementation-wise, it seems that if the PostgresHook receives a schema during initialization,
+        but it uses it as a database in the connection to Postgres:
+        https://github.com/apache/airflow/blob/main/airflow/providers/postgres/hooks/postgres.py#L96
+        """
+        # TODO: Change airflow PostgresHook to fetch database and schema separately
         database = self.hook.get_connection(self.conn_id).schema
-        return Metadata(database=database, schema=SCHEMA)
+        return Metadata(database=database, schema=self.DEFAULT_SCHEMA)
 
     def schema_exists(self, schema) -> bool:
         """
@@ -70,19 +85,22 @@ class PostgresDatabase(BaseDatabase):
         :param if_exists: Strategy to be used in case the target table already exists.
         :param chunk_size: Specify the number of rows in each batch to be written at a time.
         """
-        schema = None
-        if target_table.metadata and target_table.metadata.schema:
-            self.create_schema_if_needed(target_table.metadata.schema)
-            schema = target_table.metadata.schema.lower()
-        source_dataframe.to_sql(
-            target_table.name,
-            schema=schema,  # type: ignore
-            con=self.sqlalchemy_engine,
-            if_exists=if_exists,
-            chunksize=chunk_size,
-            method="multi",
-            index=False,
-        )
+
+        self.create_schema_if_needed(target_table.metadata.schema)
+        if not self.table_exists(table=target_table) or if_exists == "replace":
+            self.create_table(table=target_table, dataframe=source_dataframe)
+
+        output_buffer = io.StringIO()
+        source_dataframe.to_csv(output_buffer, sep=",", header=True, index=False)
+        output_buffer.seek(0)
+        table_name = self.get_table_qualified_name(target_table)
+        postgres_conn = self.hook.get_conn()
+        with closing(postgres_conn) as conn, closing(conn.cursor()) as cur:
+            cur.copy_expert(
+                f"COPY {table_name} FROM STDIN DELIMITER ',' CSV HEADER;",
+                output_buffer,
+            )
+            conn.commit()
 
     @staticmethod
     def get_table_qualified_name(table: Table) -> str:  # skipcq: PYL-R0201
@@ -120,8 +138,8 @@ class PostgresDatabase(BaseDatabase):
         self,
         source_table: Table,
         target_table: Table,
-        source_to_target_columns_map: Dict[str, str],
-        target_conflict_columns: List[str],
+        source_to_target_columns_map: dict[str, str],
+        target_conflict_columns: list[str],
         if_conflicts: MergeConflictStrategy = "exception",
     ) -> None:
         """
