@@ -1,6 +1,7 @@
 from airflow.hooks.base import BaseHook
 
-from astro.files.base import File, get_files  # noqa: F401 # skipcq: PY-W2000
+from astro.files.base import File  # noqa: F401 # skipcq: PY-W2000
+from astro.files.base import resolve_file_path_pattern  # noqa: F401 # skipcq: PY-W2000
 
 
 def check_if_connection_exists(conn_id: str) -> bool:
