@@ -1,8 +1,9 @@
+from __future__ import annotations
+
 import glob
 import os
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Dict, List, Optional, Union
 from urllib.parse import urlparse
 
 import smart_open
@@ -15,15 +16,19 @@ class BaseFileLocation(ABC):
 
     template_fields = ("path", "conn_id")
 
-    def __init__(self, path: str, conn_id: Optional[str] = None):
+    def __init__(self, path: str, conn_id: str | None = None):
         """
         Manages and provide interface for the operation for all the supported locations.
 
         :param path: Path to a file in the filesystem/Object stores
         :param conn_id: Airflow connection ID
         """
-        self.path = path
-        self.conn_id = conn_id
+        self.path: str = path
+        self.conn_id: str | None = conn_id
+
+    @property
+    def hook(self):
+        raise NotImplementedError
 
     @property
     @abstractmethod
@@ -33,12 +38,12 @@ class BaseFileLocation(ABC):
 
     @property
     @abstractmethod
-    def paths(self) -> List[str]:
+    def paths(self) -> list[str]:
         """Resolve patterns in path"""
         raise NotImplementedError
 
     @property
-    def transport_params(self) -> Union[Dict, None]:  # skipcq: PYL-R0201
+    def transport_params(self) -> dict | None:  # skipcq: PYL-R0201
         """Get credentials required by smart open to access files"""
         return None
 
@@ -123,3 +128,6 @@ class BaseFileLocation(ABC):
     def __str__(self):
         """String representation of location"""
         return self.path
+
+    def __eq__(self, other):
+        return self.path == other.path and self.conn_id == other.conn_id
