@@ -1,20 +1,31 @@
+from __future__ import annotations
+
 import io
 
 import pandas as pd
 
 from astro.constants import FileType as FileTypeConstants
 from astro.files.types.base import FileType
+from astro.utils.dataframe import convert_columns_names_capitalization
 
 
 class CSVFileType(FileType):
     """Concrete implementation to handle CSV file type"""
 
-    def export_to_dataframe(self, stream, **kwargs) -> pd.DataFrame:
+    def export_to_dataframe(
+        self, stream, columns_names_capitalization="original", **kwargs
+    ) -> pd.DataFrame:
         """read csv file from one of the supported locations and return dataframe
 
         :param stream: file stream object
+        :param columns_names_capitalization: determines whether to convert all columns to lowercase/uppercase
+            in the resulting dataframe
         """
-        return pd.read_csv(stream, **kwargs)
+        df = pd.read_csv(stream, **kwargs)
+        df = convert_columns_names_capitalization(
+            df=df, columns_names_capitalization=columns_names_capitalization
+        )
+        return df
 
     def create_from_dataframe(self, df: pd.DataFrame, stream: io.TextIOWrapper) -> None:
         """Write csv file to one of the supported locations
