@@ -1,12 +1,13 @@
-from typing import Any, Dict, List, Optional, Tuple, Union
+from __future__ import annotations
 
+from typing import Any
+
+from airflow.decorators.base import get_unique_task_id
 from airflow.models.baseoperator import BaseOperator
+from airflow.models.xcom_arg import XComArg
 
 from astro.databases import create_database
 from astro.sql.table import Table
-from astro.utils.task_id_helper import get_unique_task_id
-
-APPEND_COLUMN_TYPE = Optional[Union[List[str], Tuple[str], Dict[str, str]]]
 
 
 class AppendOperator(BaseOperator):
@@ -27,7 +28,7 @@ class AppendOperator(BaseOperator):
         self,
         source_table: Table,
         target_table: Table,
-        columns: APPEND_COLUMN_TYPE = None,
+        columns: list[str] | tuple[str] | dict[str, str] | None = None,
         task_id: str = "",
         **kwargs: Any,
     ) -> None:
@@ -54,3 +55,29 @@ class AppendOperator(BaseOperator):
             source_to_target_columns_map=self.columns,
         )
         return self.target_table
+
+
+def append(
+    *,
+    source_table: Table,
+    target_table: Table,
+    columns: list[str] | tuple[str] | dict[str, str] | None = None,
+    **kwargs: Any,
+) -> XComArg:
+    """
+    Append the source table rows into a destination table.
+
+    :param source_table: Contains the rows to be appended to the target_table (templated)
+    :param target_table: Contains the destination table in which the rows will be appended (templated)
+    :param columns: List/Tuple of columns if name of source and target tables are same.
+        If the column names in source and target tables are different pass a dictionary
+        of source_table columns names to target_table columns names.
+        Examples: ``["sell", "list"]`` or ``{"s_sell": "t_sell", "s_list": "t_list"}``
+    :param kwargs: Any keyword arguments supported by the BaseOperator is supported (e.g ``queue``, ``owner``)
+    """
+    return AppendOperator(
+        target_table=target_table,
+        source_table=source_table,
+        columns=columns,
+        **kwargs,
+    ).output
