@@ -1,6 +1,9 @@
-from typing import Any, Optional, Union
+from __future__ import annotations
+
+from typing import Any
 
 import pandas as pd
+from airflow.decorators.base import get_unique_task_id
 from airflow.models import BaseOperator
 from airflow.models.xcom_arg import XComArg
 
@@ -8,10 +11,9 @@ from astro.constants import ExportExistsStrategy
 from astro.databases import create_database
 from astro.files import File
 from astro.sql.table import Table
-from astro.utils.task_id_helper import get_task_id
 
 
-class ExportFile(BaseOperator):
+class ExportFileOperator(BaseOperator):
     """Write SQL table to csv/parquet on local/S3/GCS.
 
     :param input_data: Table to convert to file
@@ -23,7 +25,7 @@ class ExportFile(BaseOperator):
 
     def __init__(
         self,
-        input_data: Union[Table, pd.DataFrame],
+        input_data: Table | pd.DataFrame,
         output_file: File,
         if_exists: ExportExistsStrategy = "exception",
         **kwargs,
@@ -59,28 +61,31 @@ class ExportFile(BaseOperator):
 
 
 def export_file(
-    input_data: Union[Table, pd.DataFrame],
+    input_data: Table | pd.DataFrame,
     output_file: File,
     if_exists: ExportExistsStrategy = "exception",
-    task_id: Optional[str] = None,
+    task_id: str | None = None,
     **kwargs: Any,
 ) -> XComArg:
-    """Convert ExportFile into a function. Returns XComArg.
+    """Convert ExportFileOperator into a function. Returns XComArg.
 
     Returns an XComArg object of type File which matches the output_file parameter.
 
     This will allow users to perform further actions with the exported file.
 
-    e.g.
+    e.g.:
+
+    .. code-block:: python
+
+      with sample_dag:
+          table = aql.load_file(input_file=File(path=data_path), output_table=test_table)
+          exported_file = aql.export_file(
+              input_data=table,
+              output_file=File(path="/tmp/saved_df.csv"),
+              if_exists="replace",
+          )
+          res_df = aql.load_file(input_file=exported_file)
 
-        with sample_dag:
-        table = aql.load_file(input_file=File(path=data_path), output_table=test_table)
-        exported_file = aql.export_file(
-            input_data=table,
-            output_file=File(path="/tmp/saved_df.csv"),
-            if_exists="replace",
-        )
-        res_df = aql.load_file(input_file=exported_file)
 
     :param output_file: Path and conn_id
     :param input_data: Input table / dataframe
@@ -88,11 +93,9 @@ def export_file(
     :param task_id: task id, optional
     """
 
-    task_id = (
-        task_id if task_id is not None else get_task_id("export_file", output_file.path)
-    )
+    task_id = task_id or get_unique_task_id("export_file")
 
-    return ExportFile(
+    return ExportFileOperator(
         task_id=task_id,
         output_file=output_file,
         input_data=input_data,
